% The function bl_filt.m creates a unit-area lowpass filter
% with a narrow transition band (truncated sinc) in order
% to generate bandlimited, white disturbances to Ra or Qvo.
%
% Function arguments:
%	fco - desired cutoff frequency
%	Sgran - desired granularity
%
% Function outputs:
%	h - vector representing discrete-time, autonomic filter
%

function h = bl_filt(fco,Sgran)

% Forming truncated sinc filter.
hra = 2*fco*sinc(2*fco*(-60:Sgran:60));

% Normalizing the filter to unity area.
h = hra/sum(hra);





